slepc-3.18.0 2022-10-01
Report Typos and Errors

# SlepcHeaderCreate

Creates a SLEPc object

### Synopsis

    #define SlepcHeaderCreate(h,classid,class_name,descr,mansec,comm,destroy,view) \
        ((!SlepcInitializeCalled && \
        PetscError(comm,__LINE__,PETSC_FUNCTION_NAME,__FILE__,1,PETSC_ERROR_INITIAL, \
        "Must call SlepcInitialize instead of PetscInitialize to use SLEPc classes")) ||  \
        PetscHeaderCreate(h,classid,class_name,descr,mansec,comm,destroy,view))

    /* context for monitors of type XXXMonitorConverged */
    struct _n_SlepcConvMon

### Input Parameters

| classid | - the classid associated with this object
| class_name | - string name of class; should be static
| descr | - string containing short description; should be static
| mansec | - string indicating section in manual pages; should be static
| comm | - the MPI Communicator
| destroy | - the destroy routine for this object
| view | - the view routine for this object

### Output Parameter

| h | - the newly created object

### Note

This is equivalent to PetscHeaderCreate but makes sure that SlepcInitialize has been called.

### Level

developer

### Location

include/slepc/private/slepcimpl.h
Index of all sys routines
Table of Contents for all manual pages
Index of all manual pages